@@ -3,5 +3,4 @@
 from .local_sample import *
 from .linear import *
 from .memory_tensor import *
-from .multiheaded_attention import *
-from .feedforward import *
\ No newline at end of file
+from .head_generation import *
\ No newline at end of file
