@@ -4,7 +4,9 @@ A library for fast, smart transformers.
 
 """
 
-__version__ = "2.3r1"
+__version__ = "2.4r0"
 
 from . import Core # noqa
 from . import Basics #noqa
+from . import Attention
+from . import NTM
